@@ -1,26 +1,25 @@
+import math
 import os
+import random
+import re
+import string
+import warnings
+from configparser import ConfigParser
 from pathlib import Path
 from urllib.parse import urlparse
-import string
-import random
-import math
-import re
-import warnings
-from unidecode import unidecode
-from functools import wraps
-from itertools import product
-from configparser import ConfigParser
 
 import ee
+import httplib2
 from cryptography.fernet import Fernet
-from matplotlib import colors as c
 from deprecated.sphinx import deprecated, versionadded
+from matplotlib import colors as c
+from unidecode import unidecode
 
 import sepal_ui
-
-from sepal_ui import config_file
-from sepal_ui.frontend.styles import TYPES
-from .warning import SepalWarning
+from sepal_ui.conf import config, config_file
+from sepal_ui.message import ms
+from sepal_ui.scripts import decorator as sd
+from sepal_ui.scripts.warning import SepalWarning
 
 
 def hide_component(widget):
@@ -87,23 +86,6 @@ def create_download_link(pathname):
     return link
 
 
-@deprecated(
-    version="2.5.4",
-    reason="This function makes no sense outside of create_download_link. It will be removed in the next minor version",
-)
-def is_absolute(url):
-    """
-    Check if the given URL is an absolute or relative path
-
-    Args:
-        url (str): the URL to test
-
-    Return:
-        (bool): True if absolute else False
-    """
-    return bool(urlparse(str(url)).netloc)
-
-
 def random_string(string_length=3):
     """
     Generates a random string of fixed length.
@@ -115,7 +97,6 @@ def random_string(string_length=3):
         (str): A random string
     """
 
-    # random.seed(1001)
     letters = string.ascii_lowercase
 
     return "".join(random.choice(letters) for i in range(string_length))
@@ -178,141 +159,15 @@ def init_ee():
             credentials = ee.ServiceAccountCredentials(
                 service_account, "ee_private_key.json"
             )
-            ee.Initialize(credentials)
+            ee.Initialize(credentials, http_transport=httplib2.Http())
 
         # if in local env use the local user credential
         else:
-            ee.Initialize()
+            ee.Initialize(http_transport=httplib2.Http())
 
     return
 
 
-def catch_errors(alert, debug=False):
-    """
-    Decorator to execute try/except sentence
-    and catch errors in the alert message.
-    If debug is True then the error is raised anyway
-
-    Params:
-        alert (sw.Alert): Alert to display errors
-        debug (bool): Wether to raise the error or not, default to false
-    """
-
-    def decorator_alert_error(func):
-        @wraps(func)
-        def wrapper_alert_error(*args, **kwargs):
-            value = None
-            try:
-                value = func(*args, **kwargs)
-            except Exception as e:
-                alert.add_msg(f"{e}", type_="error")
-                if debug:
-                    raise e
-            return value
-
-        return wrapper_alert_error
-
-    return decorator_alert_error
-
-
-def need_ee(func):
-    """
-    Decorator to execute check if the object require EE binding.
-    Trigger an exception if the connection is not possible.
-
-    Params:
-        func (obj): the object on which the decorator is applied
-    """
-
-    @wraps(func)
-    def wrapper_ee(*args, **kwargs):
-
-        # try to connect to ee
-        try:
-            init_ee()
-        except Exception:
-            raise Exception("This function needs an Earth Engine authentication")
-
-        return func(*args, **kwargs)
-
-    return wrapper_ee
-
-
-def loading_button(alert=None, button=None, debug=False):
-    """
-    Decorator to execute try/except sentence and toggle loading button object.
-    Designed to work within the Tile object, or any object that have a self.btn and self.alert set.
-
-    Params:
-        button (sw.Btn, optional): Toggled button
-        alert (sw.Alert, optional): the alert to display the error message
-        debug (bool, optional): wether or not the exception should stop the execution. default to False
-    """
-
-    def decorator_loading(func):
-        @wraps(func)
-        def wrapper_loading(self, *args, **kwargs):
-
-            # set btn and alert
-            # Change name of variable to assign it again in this scope
-            button_ = self.btn if not button else button
-            alert_ = self.alert if not alert else alert
-
-            # Clean previous loaded messages in alert
-            alert_.reset()
-
-            button_.toggle_loading()  # Start loading
-            value = None
-            try:
-                # Catch warnings in the process function
-                with warnings.catch_warnings(record=True) as w_list:
-                    value = func(self, *args, **kwargs)
-
-                # Check if there are warnings in the function and append them
-                # Use append msg as several warnings could be triggered
-                if w_list:
-
-                    # split the warning list
-                    w_list_sepal = [
-                        w for w in w_list if isinstance(w.message, SepalWarning)
-                    ]
-
-                    # display the sepal one
-                    ms_list = [
-                        f"{w.category.__name__}: {w.message.args[0]}"
-                        for w in w_list_sepal
-                    ]
-                    [alert_.append_msg(ms, type_="warning") for ms in ms_list]
-
-                    # only display them in the console if debug mode
-                    if debug:
-
-                        def custom_showwarning(w):
-                            return warnings.showwarning(
-                                message=w.message,
-                                category=w.category,
-                                filename=w.filename,
-                                lineno=w.lineno,
-                                line=w.line,
-                            )
-
-                        [custom_showwarning(w) for w in w_list]
-
-            except Exception as e:
-                alert_.add_msg(f"{e}", "error")
-                if debug:
-                    button_.toggle_loading()  # Stop loading button if there is an error
-                    raise e
-
-            button_.toggle_loading()  # Stop loading button
-
-            return value
-
-        return wrapper_loading
-
-    return decorator_loading
-
-
 def normalize_str(msg, folder=True):
     """
     Normalize an str to make it compatible with file naming (no spaces, special chars ...etc)
@@ -374,105 +229,6 @@ def to_colors(in_color, out_type="hex"):
     return transform(out_color)
 
 
-def switch(*params, debug=True, on_widgets=[], targets=[]):
-    """
-    Decorator to switch the state of input boolean parameters on class widgets or the
-    class itself. If on_widgets is defined, it will switch the state of every widget
-    parameter, otherwise it will change the state of the class (self). You can also set
-    two decorators on the same function, one could affect the class and other the widgets.
-
-    Args:
-        *params (str): any boolean parameter of a SepalWidget.
-        debug (bool): Whether trigger or not an Exception if the decorated function fails.
-        on_widgets (list(widget_names,)|optional): List of widget names into the class
-        targets (list(bool,)|optional); list of the target value (value taht will be set on switch. default to the inverse of the current state.
-
-    """
-
-    def decorator_switch(func):
-        @wraps(func)
-        def wrapper_switch(self, *args, **kwargs):
-
-            widgets_len = len(on_widgets)
-            targets_len = len(targets)
-
-            # sanity check on targets and on_widgets
-            if widgets_len and targets_len:
-                if widgets_len != targets_len:
-                    raise IndexError(
-                        f'the length of "on_widgets" ({widgets_len}) is different from the length of "targets" ({targets_len})'
-                    )
-
-            # create the list of target values based on the target list
-            # or the initial values of the widgets params
-            # The first one is taken as reference
-            if not targets_len:
-                w = getattr(self, on_widgets[0]) if widgets_len else self
-                targets_ = [bool(getattr(w, p)) for p in params]
-            else:
-                targets_ = targets
-
-            if widgets_len:
-
-                # Verify that the input elements are strings
-                wrong_types = [
-                    (w, type(w)) for w in on_widgets if not isinstance(w, str)
-                ]
-
-                if len(wrong_types):
-                    errors = [
-                        f"Received:{w_type} for widget: {w}."
-                        for w, w_type in wrong_types
-                    ]
-
-                    raise TypeError(
-                        f"All on_widgets list elements has to be strings. [{' '.join(errors)}]"
-                    )
-
-                missing_widgets = [w for w in on_widgets if not hasattr(self, w)]
-
-                if missing_widgets:
-                    raise Exception(
-                        f"The provided {missing_widgets} widget(s) does not exist in the current class"
-                    )
-
-                def w_assign(bool_targets):
-
-                    params_targets = [
-                        (p, bool_targets[i]) for i, p in enumerate(params)
-                    ]
-
-                    for (w_name, p_t) in product(on_widgets, params_targets):
-                        param, target = p_t
-                        widget = getattr(self, w_name)
-                        setattr(widget, param, target)
-
-            else:
-
-                def w_assign(bool_targets):
-                    for i, p in enumerate(params):
-                        setattr(self, p, bool_targets[i])
-
-            # assgn the parameters to the target inverse
-            w_assign([not t for t in targets_])
-
-            # execute the function and catch errors
-            try:
-                func(self, *args, **kwargs)
-
-            except Exception as e:
-                if debug:
-                    w_assign(targets_)
-                    raise e
-
-            # reassign the parameters to the targets
-            w_assign(targets_)
-
-        return wrapper_switch
-
-    return decorator_switch
-
-
 def next_string(string):
     """
     Create a string followed by an underscore and a consecutive number
@@ -496,7 +252,33 @@ def next_string(string):
     return string
 
 
-@versionadded(version="2.7.0")
+def set_config(key, value, section="sepal-ui"):
+    """
+    Set the provided value to the given key for the given section in the sepal-ui config
+    file
+
+    Args:
+        key (str): key configuration name
+        value (str): value to be referenced by the configuration key
+        section (str, optional): configuration section, defaults to sepal-ui.
+    """
+
+    # set the section if needed
+    if "sepal-ui" not in config.sections():
+        config.add_section(section)
+
+    # set the value
+    config.set("sepal-ui", key, value)
+
+    # save back the file
+    config.write(config_file.open("w"))
+
+    return
+
+
+@deprecated(
+    version="2.9.1", reason="This function will be removed in favor of set_config()"
+)
 def set_config_locale(locale):
     """
     Set the provided local in the sepal-ui config file
@@ -524,7 +306,9 @@ def set_config_locale(locale):
     return
 
 
-@versionadded(version="2.7.0")
+@deprecated(
+    version="2.9.1", reason="This function will be removed in favor of set_config()"
+)
 def set_config_theme(theme):
     """
     Set the provided theme in the sepal-ui config file
@@ -555,7 +339,7 @@ def set_config_theme(theme):
 @versionadded(version="2.7.1")
 def set_type(color):
     """
-    Return a pre-defined material colors based on the requested type_ parameter. If the parameter is not a predifined color,
+    Return a pre-defined material colors based on the requested type\_ parameter. If the parameter is not a predifined color,
     fallback to "info" and will raise a warning. the colors can only be selected from ["primary", "secondary", "accent", "error", "info", "success", "warning", "anchor"]
 
     Args:
@@ -565,6 +349,7 @@ def set_type(color):
         (str): a pre-defined material color
 
     """
+    from sepal_ui.frontend.styles import TYPES
 
     if color not in TYPES:
         warnings.warn(
@@ -574,3 +359,89 @@ def set_type(color):
         color = TYPES[0]
 
     return color
+
+
+@versionadded(version="2.8.0")
+def geojson_to_ee(geo_json, geodesic=False, encoding="utf-8"):
+    """
+    Transform a geojson object into a featureCollection or a Geometry
+    No sanity check is performed on the initial geo_json. It must respect the
+    `__geo_interface__ <https://gist.github.com/sgillies/2217756>`__.
+
+    Args:
+        geo_json (dict): a geo_json dictionnary
+        geodesic (bool, optional): Whether line segments should be interpreted as spherical geodesics. If false, indicates that line segments should be interpreted as planar lines in the specified CRS. If absent, defaults to True if the CRS is geographic (including the default EPSG:4326), or to False if the CRS is projected. Defaults to False.
+        encoding (str, optional): The encoding of characters. Defaults to "utf-8".
+
+    Returns:
+        (ee.FeatureCollection): the created featurecollection
+    """
+
+    # from a featureCollection
+    if geo_json["type"] == "FeatureCollection":
+        for feature in geo_json["features"]:
+            if feature["geometry"]["type"] != "Point":
+                feature["geometry"]["geodesic"] = geodesic
+        features = ee.FeatureCollection(geo_json)
+        return features
+
+    # from a single feature
+    elif geo_json["type"] == "Feature":
+        geom = None
+        # Checks whether it is a point
+        if geo_json["geometry"]["type"] == "Point":
+            coordinates = geo_json["geometry"]["coordinates"]
+            longitude = coordinates[0]
+            latitude = coordinates[1]
+            geom = ee.Geometry.Point(longitude, latitude)
+        # for every other geometry simply create a geometry
+        else:
+            geom = ee.Geometry(geo_json["geometry"], "", geodesic)
+
+        return geom
+
+    # some error handling because we are fancy
+    else:
+        raise ValueError("Could not convert the geojson to ee.Geometry()")
+
+    return
+
+
+def check_input(input_, msg=ms.utils.check_input.error):
+    """
+    Check if the inpupt value is initialized.
+    If not raise an error, else return True
+
+    Args:
+        input\_ (any): the input to check
+        msg (str, optionnal): the message to display if the input is not set
+
+    Return:
+        (bool): check if the value is initialized
+    """
+
+    # by the default the variable is considered valid
+    init = True
+
+    # check the collection type that are the only one supporting the len method
+    try:
+        init = False if len(input_) == 0 else init
+    except Exception:
+        init = False if input_ is None else init
+
+    if init is False:
+        raise ValueError(msg)
+
+    return init
+
+
+################################################################################
+# the soon to be deprecated decorators
+#
+
+# fmt: off
+catch_errors = deprecated(version='3.0', reason="use sepal_ui.scripts.decorator.catch_errors instead")(sd.catch_errors)
+need_ee = deprecated(version='3.0', reason="use sepal_ui.scripts.decorator.need_ee instead")(sd.need_ee)
+loading_button = deprecated(version='3.0', reason="use sepal_ui.scripts.decorator.need_ee instead")(sd.loading_button)
+switch = deprecated(version='3.0', reason="use sepal_ui.scripts.decorator.switch instead")(sd.switch)
+# fmt: on
